==> kvpnc_0.8.6.1.orig.tar.gz: kvpnc-0.8.6.1.orig/src/profilenetworkrouteoptions.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PROFILENETWORKROUTEOPTIONS_H
#define PROFILENETWORKROUTEOPTIONS_H

#include "profilenetworkrouteoptionsbase.h"
#include <qwidget.h>

/**
@author Christoph Thielecke
*/
class ProfileNetworkRouteOptions : public ProfileNetworkRouteOptionsBase
{
public:
	ProfileNetworkRouteOptions(QWidget *parent);

	~ProfileNetworkRouteOptions();

public slots:
    void delNetworkRouteClicked();
    void addNetworkRouteClicked();
    void additionalNetworkRoutesToggled(bool);
};

#endif

==> kvpnc_0.9.0.orig.tar.gz: kvpnc-0.9.0.orig/src/profilenetworkrouteoptions.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PROFILENETWORKROUTEOPTIONS_H
#define PROFILENETWORKROUTEOPTIONS_H

#include "profilenetworkrouteoptionsbase.h"
#include <qwidget.h>
#include <qpopupmenu.h>

/**
@author Christoph Thielecke
*/
class ProfileNetworkRouteOptions : public ProfileNetworkRouteOptionsBase
{
	Q_OBJECT
public:
	ProfileNetworkRouteOptions(QWidget *parent);

	~ProfileNetworkRouteOptions();


public slots:
    void delNetworkRouteClicked();
    void addNetworkRouteClicked();
    void editNetworkRouteClicked();
    void additionalNetworkRoutesToggled(bool);
    void checkList();
    void contextMenuRequested ( QListViewItem *, const QPoint &, int );
    void doContextMenuAction ( int );

private:
	QPopupMenu *ContextMenu;

};

#endif
